/* unidata.h
 *
 * Functions for parsing the unidata text file. */

/* Copyright (C) 2002 Niels Mller
 *  
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include <wchar.h>

#include "unicode.h"

enum unidata_category
{
  UNIDATA_Lu = 1, UNIDATA_Ll, UNIDATA_Lt, UNIDATA_Lm, UNIDATA_Lo,
  UNIDATA_Mn, UNIDATA_Mc, UNIDATA_Me,
  UNIDATA_Nd, UNIDATA_Nl, UNIDATA_No,
  UNIDATA_Pc, UNIDATA_Pd, UNIDATA_Ps, UNIDATA_Pe, UNIDATA_Pi, UNIDATA_Pf, UNIDATA_Po,
  UNIDATA_Sm, UNIDATA_Sc, UNIDATA_Sk, UNIDATA_So,
  UNIDATA_Zs, UNIDATA_Zl, UNIDATA_Zp,
  UNIDATA_Cc, UNIDATA_Cf, UNIDATA_Cs, UNIDATA_Co, UNIDATA_Cn
};

/* An entry in the unicode database */
struct unidata_entry
{
  wchar_t code;
  const unsigned char *name;

  /* For ranges */
  short start;
  short end;
  enum unidata_category category;
  unsigned combining_class;
  unsigned bidirectional;
  const wchar_t *decomposition;
  int decimal_value;
  int digit_value;
  int has_numeric;
  double numeric;
  int mirrored;
  const char *unicode1_name;
  const wchar_t *upper;
  const wchar_t *lower;
  const wchar_t *title;
};

int
unidata_parse_entry(struct unidata_entry *entry,
		    const unsigned char *line);
